import { ChannelControlHelper } from "./experimental";
import { LoadBalancer, LoadBalancingConfig } from "./load-balancer";
import { SubchannelAddress } from "./subchannel-address";
interface SuccessRateEjectionConfig {
    readonly stdev_factor: number;
    readonly enforcement_percentage: number;
    readonly minimum_hosts: number;
    readonly request_volume: number;
}
interface FailurePercentageEjectionConfig {
    readonly threshold: number;
    readonly enforcement_percentage: number;
    readonly minimum_hosts: number;
    readonly request_volume: number;
}
export declare class OutlierDetectionLoadBalancingConfig implements LoadBalancingConfig {
    private readonly intervalMs;
    private readonly baseEjectionTimeMs;
    private readonly maxEjectionTimeMs;
    private readonly maxEjectionPercent;
    private readonly successRateEjection;
    private readonly failurePercentageEjection;
    private readonly childPolicy;
    constructor(intervalMs: number, baseEjectionTimeMs: number, maxEjectionTimeMs: number, maxEjectionPercent: number, successRateEjection: SuccessRateEjectionConfig | null, failurePercentageEjection: FailurePercentageEjectionConfig | null, childPolicy: LoadBalancingConfig[]);
    getLoadBalancerName(): string;
    toJsonObject(): object;
    getIntervalMs(): number;
    getBaseEjectionTimeMs(): number;
    getMaxEjectionTimeMs(): number;
    getMaxEjectionPercent(): number;
    getSuccessRateEjectionConfig(): SuccessRateEjectionConfig | null;
    getFailurePercentageEjectionConfig(): FailurePercentageEjectionConfig | null;
    getChildPolicy(): LoadBalancingConfig[];
    static createFromJson(obj: any): OutlierDetectionLoadBalancingConfig;
}
export declare class OutlierDetectionLoadBalancer implements LoadBalancer {
    private childBalancer;
    private addressMap;
    private latestConfig;
    private ejectionTimer;
    constructor(channelControlHelper: ChannelControlHelper);
    private getCurrentEjectionPercent;
    private runSuccessRateCheck;
    private runFailurePercentageCheck;
    private eject;
    private uneject;
    private runChecks;
    updateAddressList(addressList: SubchannelAddress[], lbConfig: LoadBalancingConfig, attributes: {
        [key: string]: unknown;
    }): void;
    exitIdle(): void;
    resetBackoff(): void;
    destroy(): void;
    getTypeName(): string;
}
export declare function setup(): void;
export {};
